<?php

class IMWB_Covert_Store_Content_amazon {

   var $super = null;
   var $module_name = "amazon";
   var $plugin_name = "";
   var $plugin_url = "";
   var $num_feed_urls = 100;
   var $options = Array();
   
   /**
    * The constructor is executed when the class is instatiated and the plugin gets loaded.
    * @return void
    */
   function IMWB_Covert_Store_Content_amazon(&$super) {
      $this->super = $super;
      $this->plugin_name = $super->plugin_name;
      $this->plugin_url = $super->plugin_url;

      add_action('wp_ajax_amazon_options_action', array(&$this, 'ajax_amazon_options_action_callback'));
      
      wp_register_script($this->plugin_name .'-'.$this->module_name.'-script', $this->plugin_url.'/scripts/admin_amazon_options_page.js');
   }
   
   function get_admin_options($feednum) {
      $adminOptions = array('active' => 'N',
                          	 'feedname' => '',
                            'posthours' => '4',
                            'postcount' => '5',
                            'categories' => '',
                            'catselecttype' => 'R',
                            'searchindex' => 'All',
                            'minprice' => '',
                            'maxprice' => '',
                            'keyword' => '',
                            'socshare' => 'N',
                            'socmessage' => '',
                            'lastcat' => 0,
                            'lastrun' => 0);
   		
   	$devOptions = get_option($this->plugin_name."-".$this->module_name."-".$feednum."-AdminOptions");
   	if (!empty($devOptions)) {
   		foreach ($devOptions as $key => $option)
   			$adminOptions[$key] = $option;
   	}				
//   	update_option($this->plugin_name."-".$this->module_name."-".$feednum."-AdminOptions", $adminOptions);
   	return $adminOptions;
   }
   
   function is_active(){
   
      return $this->options['active'] == 'Y' ? true : false;
   }
   
   function is_ready_to_post($feednum) {
   
      $lastrun = $this->options['lastrun'];
      if($lastrun > 0 && ($this->options['lastrun']+($this->options['posthours']*3600)) >current_time('timestamp') )
            return false;
      
      $this->options['lastrun'] = current_time('timestamp');
               
      update_option($this->plugin_name."-".$this->module_name."-".$feednum."-AdminOptions", $this->options);   
      
      return true;
   }
   
   function load_admin_scripts() {
   	wp_enqueue_script($this->plugin_name .'-'.$this->module_name.'-script');
   }
   
   function init_admin_menu() {
      $view_hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Store Content Amazon Settings', 'Amazon', 'manage_options', $this->plugin_name . '-admin-menu-'.$this->module_name, array(&$this, 'load_options_page'));	
      
      add_action( 'admin_print_scripts-' . $view_hook_name, array(&$this, 'load_admin_scripts'));	
      
      return  $view_hook_name;
   }
   
   function load_options_page() {   
   	// Include the HTML from a separate file to keep the plugin class clean
   	require "amazon_options_page.php";
   }
   
   function cron($runNow) {
   
      for($feednum = 1; $feednum <= $this->num_feed_urls; $feednum++) {
         $this->options = get_option($this->plugin_name."-".$this->module_name."-".$feednum."-AdminOptions");
         if($this->options !== false) {
   
      	   if($this->is_active()) {
               // See if module ready to run
               if($runNow || $this->is_ready_to_post($feednum)) {
                              
                  $result = $this->do_posts($feednum, stripslashes($this->options['keyword']));
                  
                  if(is_array($result)) {
                     $message = $result["error"]["module"]." - Reason: ".$result["error"]["reason"]." Message: ".$result["error"]["message"];
                     update_option($this->plugin_name."-".$this->module_name."-errors", $message);  
                  }
                  else
                     update_option($this->plugin_name."-".$this->module_name."-errors", ''); 
               }
      	   }
         }
      }
   }
   
   function get_price($item) {
   
      $lowestnewprice = (string)$item->OfferSummary->LowestNewPrice->FormattedPrice;
      $listprice = (string)$item->ItemAttributes->ListPrice->Amount;
      $post_currency = (string)$item->ItemAttributes->ListPrice->CurrencyCode;

      if(empty($lowestnewprice) || $lowestnewprice == "Too low to display" || $lowestnewprice == "Price too low to display") 
      	$post_price = $listprice;
      else {
         $post_price = (string)$item->OfferSummary->LowestNewPrice->Amount;
         $post_currency = (string)$item->OfferSummary->LowestNewPrice->CurrencyCode;
      }
//echo "Price 1:".$post_currency.$post_price." ";   
      // Now see if there is an offer
      $totOffers = $item->Offers->TotalOffers;
      if(!empty($totOffers) && $totOffers > 0) {
         // Now find the New Condition Offer
         foreach ($item->Offers->Offer as $offer) {
            if($offer->OfferAttributes->Condition == 'New') {
               $offer_price = (string)$offer->OfferListing->Price->FormattedPrice;
               if($offer_price != "Too low to display") {
                  $offer_post_price = (string)$offer->OfferListing->Price->Amount;
                  if($offer_post_price < $post_price) $post_price = $offer_post_price;
                  $post_currency = (string)$offer->OfferListing->Price->CurrencyCode;
//echo "Price 2:".$post_currency.$post_price." ";                             
               }
               $offer_saleprice = $offer->OfferListing->SalePrice;
               if(!empty($offer_saleprice) && (string)$offer_saleprice->FormattedPrice != "Too Low to Display") {
                  $offer_sale_post_price = (string)$offer_saleprice->Amount;
                  if($offer_sale_post_price < $post_price) $post_price = $offer_sale_post_price;
                  $post_currency = (string)$offer_saleprice->CurrencyCode;
//echo "Price 3:".$post_currency.$post_price." ";                             
               }
            }
         }
      }
//echo "Price 4:".$post_currency.$post_price." ";           
      // If price is still not found then try to see if collectable price available
      if(empty($post_price)) {
         $Lowestcollectibleprice = (string)$item->OfferSummary->LowestCollectiblePrice->FormattedPrice;   
         if(!empty($Lowestcollectibleprice) && $Lowestcollectibleprice != "Too low to display" && $Lowestcollectibleprice != "Price too low to display") {
            $post_price = (string)$item->OfferSummary->LowestCollectiblePrice->Amount;
            $post_currency = (string)$item->OfferSummary->LowestCollectiblePrice->CurrencyCode;     
         }
      }
//echo "Price 5:".$post_currency.$post_price."<br>";
      if(empty($post_price) || $post_price == 0)
         return false;
      
      $return['post_price'] = $post_price /100;
      $return['post_currency'] = $this->super->currency_symbols[$post_currency];
      
      return $return;
   }
   
   
   function do_posts($feed_num, $keyword, $numPosts = 0, $category_input = null, $cats_to_post_to = null, $tags_input = null, $post_status = null, $socshare = null) {
      global $wpdb;
      
      $existingProducts = false;
      $return = null;
      $numCreated = 0;
      $keyword = str_replace('"', '', trim(stripslashes($keyword)));
      
      // Get the Feed Urls to use
      if(empty($feed_num)){
         $return["error"]["module"] = "Amazon Feed";
         $return["error"]["reason"] = "No Feed Selected";
         $return["error"]["message"] = "There was no feed selected in the settings";
         return $return;
      }	
      
      $feedOptions = get_option($this->plugin_name."-".$this->module_name."-".$feed_num."-AdminOptions");
      if($feedOptions === false) {
         $return["error"]["module"] = "Amazon Feed (".$feedOptions['feedname'].")";
         $return["error"]["reason"] = "No Feed Options";
         $return["error"]["message"] = "The selected feed has no options";
         return $return;
      }	     
      
      if($numPosts == 0)
         $numPosts = rand(1, $feedOptions['postcount']);
      
      $sharePost = false;   
      if(($socshare == 'Y' && $feedOptions['socshare'] == 'Y') || ($socshare == null && $feedOptions['socshare'] == 'Y')) {         
         $sharePost = true;
         $sharePostNum = rand(1, $numPosts);
      }

      // Loop through the result pages until we create enough posts
      $page = 1;
      do {
         $minPrice = '';
         $maxPrice = '';
         if(!empty($feedOptions['minprice'])) 
            $minPrice = $feedOptions['minprice']*100;
         if(!empty($feedOptions['maxprice'])) 
            $maxPrice = $feedOptions['maxprice']*100;

      	$resultxml = $this->aws_request($this->super->options['amzregion'], array(
      		"Operation"=>"ItemSearch",
      		"AssociateTag"=>$this->super->options['amzaffid'],
      		"Keywords"=>$keyword,
      		"SearchIndex"=>$feedOptions['searchindex'],
      		"Availability" => 'Available',
      		"Condition"=>"New",
      		"ItemPage"=>$page,
      		"ReviewSort"=>"-HelpfulVotes",
      		"TruncateReviewsAt"=>"500",
      		"IncludeReviewsSummary"=>"False",
      		"ResponseGroup"=>"Large",
      		"MinimumPrice"=>$minPrice,
      		"MaximumPrice"=>$maxPrice
      		), $this->super->options['amzpubkey'], $this->super->options['amzprikey']);		
      
         if(!empty($resultxml["error"])) {return $resultxml;}
         
         if (isset($resultxml->Error)) {
         	$message = '<p>There was a problem with your Amazon API request:</p><p><i><b>'.$resultxml->Error->Code.':</b> '.$resultxml->Error->Message.'</i></p>';	
         	$return["error"]["module"] = "Amazon ($keyword)";
         	$return["error"]["reason"] = "API fail";
         	$return["error"]["message"] = $message;	
         	return $return;
         }
         
         if (isset($resultxml->Items->Error)) {
         	$message = '<p>There was a problem with your Amazon API request:</p><p><i><b>'.$resultxml->Items->Error->Code.':</b> '.$resultxml->Items->Error->Message.'</i></p>';	
         	$return["error"]["module"] = "Amazon ($keyword";
         	$return["error"]["reason"] = "API fail";
         	$return["error"]["message"] = $message;	
         	return $return;
         }
         
         if (isset($resultxml->Items->Request->Errors)) {
           	$return["error"]["module"] = "Amazon";
            $return["error"]["reason"] = "API fail";
           	$errorCode = (string)$resultxml->Items->Request->Errors->Error->Code;

            if($errorCode == "AWS.ECommerceService.NoExactMatches") {
               $return["error"]["reason"] = "Amazon";
               if($existingProducts)
                  $message = 'Sorry, there are no more products for that search term. Please try using a different keyword or phrase to find more products.';
               else
                  $message = 'Sorry, we couldn\'t find any products for that search term. Please try using a different keyword or phrase';
            }
            else {
            	$message = 'There was a problem with your Amazon API request: <i><b>'.$resultxml->Items->Request->Errors->Error->Code.':</b> '.$resultxml->Items->Request->Errors->Error->Message.'</i>';	
            }

            $return["error"]["message"] = $message;	
         	return $return;
         }
   
         foreach($resultxml->Items->Item as $item) {	

            // Get the title
            $post_title = (string)$item->ItemAttributes->Title;
            
            // Check for exisintg post         
   			$results = $wpdb->get_row( $wpdb->prepare("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = %s AND meta_value = %s", 'imwb_cc_amazon_asin', trim($item->ASIN)) );
   			
   			if(count($results) > 0){
   				$existingProducts = true;
   			   continue;			   
   			}
   			   			   
            $post_link = trim((string)$item->DetailPageURL);
            
            // Get the description
            $desc = "";
            if (isset($item->EditorialReviews->EditorialReview)) {
   				foreach($item->EditorialReviews->EditorialReview as $descs) {
   					$desc .= strip_tags((string)$descs->Content, "<img><p><br><br/><h1><h2><h3><h4>");
   				}		
   			}	
   			
   			// If select to have feature list then include it in the description
   			$featureList = "";
   			if($this->super->options['amzincfeatures'] == 'Y') {  		
   				if (isset($item->ItemAttributes->Feature)) {	
   					$featureList = "<h3>Product Features</h3><ul>";
   					foreach($item->ItemAttributes->Feature as $feature) {
   						$posx = strpos($feature, "href=");
   						if ($posx === false) {
   							$featureList .= "<li>".$feature."</li>";		
   						}
   					}	
   					$featureList .= "</ul>";				
   				}
   			}
               
            // get category
            if(empty($cats_to_post_to))
               $post_category = $this->super->get_post_categories(htmlspecialchars(stripslashes($feedOptions['categories'])),$feedOptions['catselecttype'], $keyword);
            else 
               $post_category = $this->super->get_post_categories($category_input ,$cats_to_post_to, $keyword);
               
            // Get the Price & Currency
            $itemPrice = $this->get_price($item);
            if($itemPrice === false)
               continue;
               
            $post_price =  $itemPrice['post_price'];
            $post_currency = $itemPrice['post_currency'];   
       
            // Get the Price & Currency
//            $lowestnewprice = (string)$item->OfferSummary->LowestNewPrice->FormattedPrice;
//            $listprice = (string)$item->ItemAttributes->ListPrice->Amount;
//            $post_currency = (string)$item->ItemAttributes->ListPrice->CurrencyCode;
//            $post_currency = $this->super->currency_symbols[$post_currency];
//            
//            if(empty($lowestnewprice) || $lowestnewprice == "Too low to display" || $lowestnewprice == "Price too low to display") 
//            	$post_price = $listprice;
//            else {
//               $post_price = (string)$item->OfferSummary->LowestNewPrice->Amount;
//               $post_currency = (string)$item->OfferSummary->LowestNewPrice->CurrencyCode;
//               $post_currency = $this->super->currency_symbols[$post_currency];
//            }
            
            // Now see if there is an offer
//            $totOffers = $item->Offers->TotalOffers;
//            if(isset($totOffers) && $totOffers > 0) {
               // Now find the New Condition Offer
//               foreach ($item->Offers->Offer as $offer) {
//                  if($offer->OfferAttributes->Condition == 'New') {
//                     $offer_price = (string)$offer->OfferListing->Price->FormattedPrice;
//                     if($offer_price != "Too low to display") {
//                        $post_price = (string)$offer->OfferListing->Price->Amount;
//                        $post_currency = (string)$offer->OfferListing->Price->CurrencyCode;
//                        $post_currency = $this->super->currency_symbols[$post_currency];      
//                     }
//                  }
//               }
//            }
            
            // If price is still not found then try to see if collectable price available
//            if(empty($post_price)) {
//               $Lowestcollectibleprice = (string)$item->OfferSummary->LowestCollectiblePrice->FormattedPrice;   
//               if(!empty($Lowestcollectibleprice) && $Lowestcollectibleprice != "Too low to display" && $Lowestcollectibleprice != "Price too low to display") {
//                  $post_price = (string)$item->OfferSummary->LowestCollectiblePrice->Amount;
//                  $post_currency = (string)$item->OfferSummary->LowestCollectiblePrice->CurrencyCode;
//                  $post_currency = $this->super->currency_symbols[$post_currency];      
//               }
//            }
            
//            if(empty($post_price)) 
//               continue;
//                           
//            $post_price = $post_price /100;
                     
            // Get The Tags
            if(empty($tags_input)) {
               $post_tags = array();	
               if($this->super->options['createtags'] == 'Y') {
                  $post_tags = $this->super->get_tags($post_title);
               }
            }
            else 
               $post_tags = $tags_input;

            // Save Post
            $post_content = wpautop($desc.$featureList);
            $post_type = "post";
            $post_date = current_time('mysql');
            $post_date_gmt = current_time('mysql', 1);
            $post_author = 1;
            if(empty($post_status))
               $post_status = $this->super->options['posttype'] == '0' ? 'publish' : 'draft';

           // echo "Title: $post_title<br>Content: $post_content<br>CatId:$post_category<br>AuthorId:$post_author<br><br>";

           	$post_data = compact('post_content','post_title','post_date','post_date_gmt','post_author','post_category', 'post_status', 'post_type');		
            $post_data['tags_input'] = implode(',', $post_tags);
            $post_data = add_magic_quotes($post_data);
            $postId = wp_insert_post($post_data);
            if (is_wp_error($postId)) {
               $return["error"]["module"] = "Amazon ($keyword)";
               $return["error"]["reason"] = "Error Inserting Post";
               $return["error"]["message"] = $postId->get_error_message();	
               return $return;
            }
            
            // Store the product ID so we don't post duplicates
            update_post_meta( $postId , 'imwb_cc_amazon_asin', trim($item->ASIN) );
            
            // Set the last updated time to now
            update_post_meta( $postId, '_imwb_cc_amazon_asin_updated', time());
            
            // Update Featured image
            $post_image = $item->LargeImage->URL;
            if($post_image == "") {$post_image = $item->MediumImage->URL;}	
            if($post_image != "") 
               $this->super->set_featured_image($postId, $post_image);
            
            // Set CSB Metadata fields
            update_post_meta( $postId, 'imwb_zonpress_post_producturl', $post_link);
            update_post_meta( $postId, 'imwb_zonpress_post_price', $post_price);
            update_post_meta( $postId, 'imwb_zonpress_post_currency', $post_currency);
            update_post_meta( $postId, '_imwb_zonpress_post_imp', 0 );
            update_post_meta( $postId, '_imwb_zonpress_post_clicks', 0);
            update_post_meta( $postId, '_imwb_zonpress_post_ctr', 0);
            
            // Set other IMWB plugins/themes metadata
            update_post_meta( $postId, 'imwb_interest_post_link_url', $post_link);
            update_post_meta( $postId, 'imwb_interest_post_link_text', 'From Amazon');
            
            $numCreated++;
            
            // Comments
            if($this->super->options['addcomments'] == 'Y') {
               $CustomerReviewsURL = $item->CustomerReviews->IFrameURL;
               $response = wp_remote_get( $CustomerReviewsURL);
               if( !is_wp_error( $response ) ) {
                  $content = $response['body'];
                  if (preg_match('#<body[^>]*>(.*?)</body>#si', $content, $body)) 
                     $this->do_comments($postId, $body[1]); 
               }            
            }     
            
            if($sharePost == true && $sharePostNum == $numCreated && $post_status == 'publish') {  
               $this->super->post_to_social_networks($postId, $feedOptions['socmessage']);
            }
            
            if( $numCreated == $numPosts)
               break;
         }
         

         // Page Loop
         if( $numCreated == $numPosts)
            break;         
            
         $page++;
                     
      } while($page <= 5);   
      
      return $numCreated;
   }
      
   function do_comments($postId, $commentsHTML) {

      $dom = new DOMDocument();
      $dom->preserveWhiteSpace = false;
      $dom->loadHTML($commentsHTML);	
 
   	$xpath = new DOMXPath($dom);
   	
      $comments = array();
      
      $nodes = $xpath->query("//table[@class='crIFrameReviewList']//tr/td/div");		
      $y=0;
      foreach($nodes as $node) {
         $title = $xpath->query("div/b", $node)->item(0);
         $comments[$y]["title"] = $title->textContent;
         $desc = $xpath->query("div[@class='reviewText']", $node)->item(0);
         if($desc === NULL) 
            $comments[$y]["content"] = trim(strip_tags(preg_replace('/<([\w]+)[^>]*>(.*?)<\/\1>/s', '', $dom->saveHTML($node))));
         else
            $comments[$y]["content"] = $desc->textContent;
         $author = $xpath->query("div/div/div/a/span", $node)->item(0);
         $comments[$y]["author"] = $author->textContent;
         
         $y++;
      }
            
      // Add comment is any found
      if(count($comments) == 0)
         return;
         
      if($this->options['randcomments'] == 'Y') {
      	$totCount = count($comments);
      	$half = ceil($totCount / 2);
      	$cnum = rand($half,$totCount);
      } else {
      	$cnum = count($comments);
      }   

   	$comment_ts = current_time('timestamp');	
   	
      $i = 0;
		foreach ($comments as $comment) {
			if($i == $cnum) 
			   break;
			   
			$comment_post_ID=$postId;
			$comment_ts = $comment_ts + (rand(0, 30) * 60 + rand(0, 59));
         $comment_date = date('Y-m-d H:i:s', $comment_ts);
			$rnd= rand(1,9999);
			$comment_author_email="noreply$rnd@yourdomain.com";
			$comment_author=$comment["author"];
			$comment_author_url='';  
			$comment_content='<strong>'.$comment["title"].'</strong> '.$comment["content"];			
			$comment_type='';
			$user_ID='';
			$comment_approved = 1;
			$commentdata = compact('comment_post_ID', 'comment_date', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type', 'user_ID', 'comment_approved');
			$comment_id = wp_insert_comment( $commentdata );
			$i++;
		}
   }
   
   
   function aws_request($region, $params, $public_key, $private_key) {
   	libxml_use_internal_errors(true);
   	$method = "GET";
//   	$host = "ecs.amazonaws.".$region;
   	$host = "webservices.amazon.".$region;
   	$uri = "/onca/xml";
   
   	$params["Service"] = "AWSECommerceService";
   	$params["AWSAccessKeyId"] = $public_key;
   	
   	$t = time() + 10000;
   	$params["Timestamp"] = gmdate("Y-m-d\TH:i:s\Z",$t);	
   	$params["Version"] = "2011-08-01";
   	ksort($params);
   	
   	$canonicalized_query = array();
   	foreach ($params as $param=>$value) {
   		$param = str_replace("%7E", "~", rawurlencode($param));
   		$value = str_replace("%7E", "~", rawurlencode($value));
   		$canonicalized_query[] = $param."=".$value;
   	}
   
   	$canonicalized_query = implode("&", $canonicalized_query);
   	$string_to_sign = $method."\n".$host."\n".$uri."\n".$canonicalized_query;   
   	$signature = base64_encode(hash_hmac("sha256", $string_to_sign, $private_key, True));  
   	$signature = str_replace("%7E", "~", rawurlencode($signature));  
   	$request = "http://".$host.$uri."?".$canonicalized_query."&Signature=".$signature; 
//      echo $request."<br><br>";
   	
   	$response = wp_remote_get($request);
      if( is_wp_error( $response ) ) {
   	      $return["error"]["module"] = "Amazon";
   	      $return["error"]["reason"] = "Error Connecting to Amazon API";
   	      $return["error"]["message"] = $response->get_error_message();	
   	      return $return;
     }	 	
//    echo '<br><br>Response:<pre>';
//      print_r( $response['body'] );
//      echo '</pre>';
     $pxml = simplexml_load_string($response['body']);
     if ($pxml === False) {
   		$emessage = "Failed loading XML, errors returned: ";
   		foreach(libxml_get_errors() as $error) {
   			$emessage .= $error->message . ", ";
   		}	
   		libxml_clear_errors();
   		$return["error"]["module"] = "Amazon";
   		$return["error"]["reason"] = "XML Error";
   		$return["error"]["message"] = $emessage;	
   		return $return;			
   	} else {
   		return $pxml;
   	}
   } 
  // AJAX callbacks
   function ajax_amazon_options_action_callback() {
   	global $wpdb; // this is how you get access to the database
   
   	$feedNum = intval( $_POST['num'] );
   	$feedAction = $_POST['cmd'];
   	
   	if($feedAction == 'del') {
      	delete_option($this->plugin_name."-".$this->module_name."-".$feedNum."-AdminOptions");
      	echo "";
      	die();
      }
      
      $this->options = $this->get_admin_options($feedNum);
      //US
      $searchIndex_options['com'] = Array("All" => "All", "Apparel" => "Apparel", "Appliances" => "Appliances", "ArtsAndCrafts" => "ArtsAndCrafts", "Automotive" => "Automotive", "Baby" => "Baby", "Beauty" => "Beauty", "Books" => "Books", "Classical" => "Classical", "Collectibles" => "Collectibles", "DigitalMusic" => "DigitalMusic", "Grocery" => "Grocery", "DVD" => "DVD", "Electronics" => "Electronics", "HealthPersonalCare" => "HealthPersonalCare", "HomeGarden" => "HomeGarden", "Industrial" => "Industrial", "Jewelry" => "Jewelry", "KindleStore" => "KindleStore", "Kitchen" => "Kitchen", "LawnAndGarden" => "LawnAndGarden", "Magazines" => "Magazines", "Marketplace" => "Marketplace", "Merchants" => "Merchants", "Miscellaneous" => "Miscellaneous", "MobileApps" => "MobileApps", "MP3Downloads" => "MP3Downloads", "Music" => "Music", "MusicalInstruments" => "MusicalInstruments", "MusicTracks" => "MusicTracks", "OfficeProducts" => "OfficeProducts", "OutdoorLiving" => "OutdoorLiving", "PCHardware" => "PCHardware", "PetSupplies" => "PetSupplies", "Photo" => "Photo", "Shoes" => "Shoes", "Software" => "Software", "SportingGoods" => "SportingGoods", "Tools" => "Tools", "Toys" => "Toys", "UnboxVideo" => "UnboxVideo", "VHS" => "VHS", "Video" => "Video", "VideoGames" => "VideoGames", "Watches" => "Watches", "Wireless" => "Wireless", "WirelessAccessories" => "WirelessAccessories");
      //UK
      $searchIndex_options['co.uk'] = Array("All" => "All","Apparel" => "Apparel","Automotive" => "Automotive","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Classical" => "Classical","DVD" => "DVD","Electronics" => "Electronics","Grocery" => "Grocery","HealthPersonalCare" => "HealthPersonalCare","HomeGarden" => "HomeGarden","Jewelry" => "Jewelry","KindleStore" => "KindleStore","Kitchen" => "Kitchen","Lighting" => "Lighting","Marketplace" => "Marketplace","MP3Downloads" => "MP3Downloads","Music" => "Music","MusicalInstruments" => "MusicalInstruments","MusicTracks" => "MusicTracks","OfficeProducts" => "OfficeProducts","OutdoorLiving" => "OutdoorLiving","Outlet" => "Outlet","Shoes" => "Shoes","Software" => "Software","SoftwareVideoGames" => "SoftwareVideoGames","Toys" => "Toys","VHS" => "VHS","Video" => "Video","VideoGames" => "VideoGames","Watches" => "Watches");
      //JP
      $searchIndex_options['co.jp'] = Array("All" => "All","Apparel" => "Apparel","Appliances" => "Appliances","Automotive" => "Automotive","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Classical" => "Classical","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","Grocery" => "Grocery","HealthPersonalCare" => "HealthPersonalCare","Hobbies" => "Hobbies","HomeImprovement" => "HomeImprovement","Jewelry" => "Jewelry","KindleStore" => "KindleStore","Kitchen" => "Kitchen","Marketplace" => "Marketplace","MobileApps" => "MobileApps","MP3Downloads" => "MP3Downloads","Music" => "Music","MusicalInstruments" => "MusicalInstruments","MusicTracks" => "MusicTracks","OfficeProducts" => "OfficeProducts","Shoes" => "Shoes","Software" => "Software","SportingGoods" => "SportingGoods","Toys" => "Toys","VHS" => "VHS","Video" => "Video","VideoGames" => "VideoGames","Watches" => "Watches");
      //IT
      $searchIndex_options['it'] = Array("All" => "All","Automotive" => "Automotive","Baby" => "Baby","Books" => "Books","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","Garden" => "Garden","KindleStore" => "KindleStore","Kitchen" => "Kitchen","Lighting" => "Lighting","MP3Downloads" => "MP3Downloads","Music" => "Music","Shoes" => "Shoes","Software" => "Software","Toys" => "Toys","VideoGames" => "VideoGames","Watches" => "Watches");
      //FR
      $searchIndex_options['fr'] = Array("All" => "All","Apparel" => "Apparel","Automotive" => "Automotive","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Classical" => "Classical","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","HealthPersonalCare" => "HealthPersonalCare","HomeImprovement" => "HomeImprovement","Jewelry" => "Jewelry","KindleStore" => "KindleStore","Kitchen" => "Kitchen","Lighting" => "Lighting","MP3Downloads" => "MP3Downloads","Music" => "Music","MusicalInstruments" => "MusicalInstruments","MusicTracks" => "MusicTracks","OfficeProducts" => "OfficeProducts","Outlet" => "Outlet","PetSupplies" => "PetSupplies","Shoes" => "Shoes","Software" => "Software","SoftwareVideoGames" => "SoftwareVideoGames","VHS" => "VHS","Video" => "Video","VideoGames" => "VideoGames","Watches" => "Watches");
      //ES
      $searchIndex_options['es'] = Array("All" => "All","Automotive" => "Automotive","Baby" => "Baby","Books" => "Books","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","KindleStore" => "KindleStore","Kitchen" => "Kitchen","MP3Downloads" => "MP3Downloads","Music" => "Music","Shoes" => "Shoes","Software" => "Software","Toys" => "Toys","VideoGames" => "VideoGames","Watches" => "Watches");
      //DE
      $searchIndex_options['de'] = Array("All" => "All","Apparel" => "Apparel","Automotive" => "Automotive","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Classical" => "Classical","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","Grocery" => "Grocery","HealthPersonalCare" => "HealthPersonalCare","HomeGarden" => "HomeGarden","Jewelry" => "Jewelry","KindleStore" => "KindleStore","Kitchen" => "Kitchen","Lighting" => "Lighting","Magazines" => "Magazines","Marketplace" => "Marketplace","MP3Downloads" => "MP3Downloads","Music" => "Music","MusicalInstruments" => "MusicalInstruments","MusicTracks" => "MusicTracks","OfficeProducts" => "OfficeProducts","OutdoorLiving" => "OutdoorLiving","Outlet" => "Outlet","PCHardware" => "PCHardware","Photo" => "Photo","Software" => "Software","SoftwareVideoGames" => "SoftwareVideoGames","SportingGoods" => "SportingGoods","Tools" => "Tools","Toys" => "Toys","VHS" => "VHS","Video" => "Video","VideoGames" => "VideoGames","Watches" => "Watches");
      //CN
      $searchIndex_options['cn'] = Array("All" => "All","Apparel" => "Apparel","Appliances" => "Appliances","Automotive" => "Automotive","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Electronics" => "Electronics","Grocery" => "Grocery","HealthPersonalCar" => "HealthPersonalCare","Home" => "Home","HomeImprovement" => "HomeImprovement","Jewelry" => "Jewelry","KindleStore" => "KindleStore","Misc" => "Misc","Music" => "Music","OfficeProducts" => "OfficeProducts","PetSupplies" => "PetSupplies","Photo" => "Photo","Shoes" => "Shoes","Software" => "Software","SportingGoods" => "SportingGoods","Toys" => "Toys","Video" => "Video","VideoGames" => "VideoGames","Watches" => "Watches");
      //CA
      $searchIndex_options['ca'] = Array("All" => "All","Baby" => "Baby","Beauty" => "Beauty","Books" => "Books","Classical" => "Classical","DVD" => "DVD","Electronics" => "Electronics","ForeignBooks" => "ForeignBooks","HealthPersonalCare" => "HealthPersonalCare","KindleStore" => "KindleStore","Kitchen" => "Kitchen","LawnAndGarden" => "LawnAndGarden","Music" => "Music","PetSupplies" => "PetSupplies","Software" => "Software","SoftwareVideoGames" => "SoftwareVideoGames","VHS" => "VHS","Video" => "Video","VideoGames" => "VideoGames");
      //IN
      $searchIndex_options['in'] = Array("Books" => "Books","DVD" => "DVD","Electronics" => "Electronics","Marketplace" => "Marketplace");     
                                    
      ob_start();
?>   

<input type="hidden" name="imwb_covertstorecontent_pro_amazon_options[lastrun]" value="<?php echo $this->options['lastrun'] ?>">
<input type="hidden" name="amazonfeednum" value="<?php echo $feedNum; ?>">

<table class="widefat">
 <thead>
  <tr>
   <th scope="col" colspan="2">Amazon Feed Settings</th>
  </tr>
</thead>
   <tbody style="display: table-row-group;">
   <tr valign="top"><td width="350px">Name</td>
   	<td>
   		<input id="imwb_covertstorecontent_pro_amazon_options_feedname" class="regular-text" type="text" name="imwb_covertstorecontent_pro_amazon_options[feedname]" value="<?php echo htmlspecialchars(stripslashes($this->options['feedname'])) ?>" size="40"/>
   		 <label class="description" for="imwb_covertstorecontent_pro_amazon_options[feedname]">Enter a unique name to identify this feed</label>
   	</td>
   </tr>

<tr><td colspan="2"><strong>Keyword Search</strong></td></tr>
<tr valign="top"><td width="350px">Select keywords to use</td>
<td>
<select size="10" style="width:25em; height:  200px;" name="imwb_covertstorecontent_pro_amazon_options[keyword]" id="imwb_covertstorecontent_pro_amazon_options_keywords" >
<?php 
$selectedKeyword = htmlspecialchars(stripslashes($this->options['keyword']));
$keywords = preg_split("/[\s]\n+/", htmlspecialchars(stripslashes($this->super->options['keywords'])));
foreach ($keywords as $key => $value) {
   echo "<option value='".esc_attr($value)."'";
   if($value == $selectedKeyword )
   	echo " selected='selected' ";
   echo ">$value</option>";
}
?>
</select>
</td>
</tr>

<tr valign="top"><td width="350px">Restrict search to the following Amazon search index</td>
<td>
<select size="10" style="width:25em; height:  200px;" id="imwb_covertstorecontent_pro_amazon_options[searchindex]" name="imwb_covertstorecontent_pro_amazon_options[searchindex]">
<?php 
 foreach ($searchIndex_options[$this->super->options['amzregion']] as $key => $label) {
    $selected = ($this->options['searchindex'] == $key) ? " selected" : "";
    echo "<option value='{$key}'{$selected}>{$label}</option>";
 }
?>
</select>
</td>
</tr>
<tr valign="top"><td width="350px">Restrict search to products in the following price range<br><small>Leave blank for no price range search</small></td>
<td>
Minimum Price: <input id="imwb_covertstorecontent_pro_amazon_options_minprice" type="text" name="imwb_covertstorecontent_pro_amazon_options[minprice]" value="<?php echo $this->options['minprice'] ?>" size="10"/>
Maximum Price: <input id="imwb_covertstorecontent_pro_amazon_options_maxprice"  type="text" name="imwb_covertstorecontent_pro_amazon_options[maxprice]" value="<?php echo $this->options['maxprice'] ?>" size="10"/>
 <label class="description" for="imwb_covertstorecontent_pro_amazon_options[minprice]">Enter prices to 2 decimal places. I.e. 10.99, 10.00, 1000.00 etc</label>

</td>
</tr>
<tr><td colspan="2"><strong>Categories To Use</strong></td></tr>
<tr valign="top"><td width="350px">Select categories to post to</td>
<td>
<input id="imwb_covertstorecontent_pro_amazon_options_catselecttype" type="radio" name="imwb_covertstorecontent_pro_amazon_options[catselecttype]" value="M" <?php echo $this->options['catselecttype'] == "M" ? "checked='Yes'" : "" ?> /> Post to category that matches keyword. Create if no match. <br>
<input id="imwb_covertstorecontent_pro_amazon_options_catselecttype" type="radio" name="imwb_covertstorecontent_pro_amazon_options[catselecttype]" value="R" <?php echo $this->options['catselecttype'] == "R" ? "checked='Yes'" : "" ?> /> Post to one category picked at random from your selection below <br>
<input id="imwb_covertstorecontent_pro_amazon_options_catselecttype" type="radio" name="imwb_covertstorecontent_pro_amazon_options[catselecttype]" value="A" <?php echo $this->options['catselecttype'] == "A" ? "checked='Yes'" : "" ?> /> Post to all selected categories<br><br>
<select size="10"  multiple="multiple"  style="width:25em; height:auto;" name="imwb_covertstorecontent_pro_amazon_options[categories][]" id="imwb_covertstorecontent_pro_amazon_options_categories" >
<?php 
   $currentCategories = explode(",", htmlspecialchars(stripslashes($this->options['categories'])) );
   echo	$this->super->get_blog_categories(0, $currentCategories ); 
?>
</select>
<br>
<p><a href="javascript:void(0)" onclick="imwb_covertstorecontent_pro_selectAll(document.getElementById('imwb_covertstorecontent_pro_amazon_options_categories'))"><?php _e('Select All','imwb_covertstorecontent'); ?></a> / <a href="javascript:void(0)" onclick="imwb_covertstorecontent_pro_unselectAll(document.getElementById('imwb_covertstorecontent_pro_amazon_options_categories'))"><?php _e('Unselect All','imwb_covertstorecontent'); ?></a></p>
</td>
</tr>

<tr><td colspan="2"><strong>Auto Blogging</strong></td></tr>
<tr valign="top"><td width="350px">Set this active and start auto blogging</td>
<td>
<input id="imwb_covertstorecontent_pro_amazon_options[active]" type="checkbox" name="imwb_covertstorecontent_pro_amazon_options[active]" value="Y" <?php echo $this->options['active'] == "Y" ? "checked='Yes'" : "" ?> /></td>
</tr>
<tr valign="top"><td width="350px">Post Creation</h3></td>
<td>
Create between 1 and  <input id="imwb_covertstorecontent_pro_amazon_options[postcount]" type="text" name="imwb_covertstorecontent_pro_amazon_options[postcount]" value="<?php echo $this->options['postcount'] ?>" size="3"> posts every <input id="imwb_covertstorecontent_pro_amazon_options[posthours]" type="text" name="imwb_covertstorecontent_pro_amazon_options[posthours]" value="<?php echo $this->options['posthours'] ?>" size="3"> hours
</td>
</tr>
<tr valign="top"><td width="350px">Auto Post Message to Social Networks<br><small>One message will be posted per autoblogging session for a post chosen randomly, providing the posts are published and not draft</small></td>
<td>
<input id="imwb_covertstorecontent_pro_amazon_options[socshare]" type="checkbox" name="imwb_covertstorecontent_pro_amazon_options[socshare]" value="Y" <?php echo $this->options['socshare'] == "Y" ? "checked='Yes'" : "" ?> /></td>
</tr>
<tr valign="top"><td width="350px">Message</td>
<td><input id="imwb_covertstorecontent_pro_amazon_options[socmessage]" type="text" name="imwb_covertstorecontent_pro_amazon_options[socmessage]" value="<?php echo $this->options['socmessage'] ?>" size="90">
</td>
</tr>

<tr><td colspan="2"><div class="submit">
<input class="button-primary" type="submit" name="update_imwb_covertstorecontentamazonSettings" value="<?php echo $feedAction == 'add' ? 'Create Feed' : 'Update Feed';?>" />
</div></td></tr>
</tbody>
</table>

<?php   

      $output = ob_get_contents();
      ob_end_clean();
      echo $output;

   	die(); // this is required to return a proper result
   
   }
   
}


?>